package com.inspect.metadata.eqpbook.mapper;

import com.inspect.metadata.eqpbook.domain.BasedataUavResumeInfo;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface BasedataUavResumeInfoMapper {
    BasedataUavResumeInfo selectBasedataUavResumeInfoByRecordId(Long recordId);

    List<BasedataUavResumeInfo> selectBasedataUavResumeInfoList(BasedataUavResumeInfo resumeInfo);

    int insertBasedataUavResumeInfo(BasedataUavResumeInfo resumeInfo);

    int updateBasedataUavResumeInfo(BasedataUavResumeInfo resumeInfo);

    int deleteBasedataUavResumeInfoByRecordId(Long recordId);

    int deleteBasedataUavResumeInfoByRecordIds(Long[] recordIds);
}
